==> nuke-touchable-highlight-0.0.1.tgz: package/theme/index.jsx <==
import {createElement, Component,render} from 'rax';
import View from 'nuke-view';
import Text from 'nuke-text';
import TouchableHighlight from 'nuke-touchable-highlight';
import BizPage from 'nuke-biz-page';

class App extends Component {
    constructor() {
        super();
        this.state = {
            count : 0
        }
    }
    press = (e) =>{
        this.setState({
            count: this.state.count+1
        })
    }
    render() {
        return (
            <BizPage title="TouchableHighlight">
                <BizPage.Intro main="Normal"></BizPage.Intro>
                <View style={styles.result}>
                    {this.state.count ? <Text style={styles.resultText}>点击 {this.state.count} 次</Text> :null}
                </View>
                <View style={styles.btns}>
                    <TouchableHighlight style={styles.touch} activeStyle={{backgroundColor:'#1170bc'}} onPress={this.press.bind(this)}>
                        <Text style={styles.touchText}>点击</Text>
                    </TouchableHighlight>
                </View>
                
            </BizPage>
        )
    }
}
const styles = {
    result : {
        height:'480rem',
        margin:'30rem',
        padding:'10rem',
        backgroundColor:'#ffffff',
        justifyContent:'center',
        alignItems:'center'
    },
    resultText : {
        fontSize:'28rem'
    },
    btns:{
        margin:'30rem',
    },
    touch:{
        backgroundColor:'#3089dc',
        height:'56rem',
        justifyContent:'center',
        alignItems:'center'
    },
    touchText:{
        color:'#ffffff',
        fontSize:'28rem'
    }
}

render(<App/>);

==> nuke-touchable-highlight-0.0.2.tgz: package/theme/index.jsx <==
import {createElement, Component,render} from 'rax';
import View from 'nuke-view';
import Text from 'nuke-text';
import TouchableHighlight from 'nuke-touchable-highlight';
import Page from 'nuke-page';

class App extends Component {
    constructor() {
        super();
        this.state = {
            count : 0
        }
    }
    press = (e) =>{
        this.setState({
            count: this.state.count+1
        })
    }
    render() {
        return (
            <Page title="TouchableHighlight">
                <Page.Intro main="Normal"></Page.Intro>
                <View style={styles.result}>
                    {this.state.count ? <Text style={styles.resultText}>点击 {this.state.count} 次</Text> :null}
                </View>
                <View style={styles.btns}>
                    <TouchableHighlight style={styles.touch} activeStyle={{backgroundColor:'#1170bc'}} onPress={this.press.bind(this)}>
                        <Text style={styles.touchText}>点击</Text>
                    </TouchableHighlight>
                </View>
                
            </Page>
        )
    }
}
const styles = {
    result : {
        height:'480rem',
        margin:'30rem',
        padding:'10rem',
        backgroundColor:'#ffffff',
        justifyContent:'center',
        alignItems:'center'
    },
    resultText : {
        fontSize:'28rem'
    },
    btns:{
        margin:'30rem',
    },
    touch:{
        backgroundColor:'#3089dc',
        height:'56rem',
        justifyContent:'center',
        alignItems:'center'
    },
    touchText:{
        color:'#ffffff',
        fontSize:'28rem'
    }
}

render(<App/>);
